@@ -1,8 +1,10 @@
 #!/usr/bin/python
 
+import sys
+import unittest
+import pytest
 import pyrana.packet
 import pyrana.errors
-import unittest
 from tests.mockslib import MockFF
 
 
@@ -46,6 +48,13 @@ class TestPacket(unittest.TestCase):
         assert pkt
         assert repr(pkt)
 
+    @pytest.mark.skipif(sys.version_info < (3,),
+                       reason="requires python3")
+    def test_repr_str_equals(self):
+        pkt = pyrana.packet.Packet()
+        assert pkt
+        assert (repr(pkt) == str(pkt))
+
     def test_data_values_matches(self):
         pkt = pyrana.packet.Packet(0, _B)
         self.assertTrue(pkt.data == _B)
@@ -129,6 +138,12 @@ class TestPacket(unittest.TestCase):
         with pkt.raw_pkt() as cpkt:
             assert(cpkt)
 
+    def test_get_item(self):
+        f = pyrana.packet.Packet(0, b'cthlhu')
+        for i in range(len(f)):
+            assert(f[i] == f.data[i])
+
+
 
 if __name__ == "__main__":
     unittest.main()
